#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_DOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_DOT_HPP_INCLUDED

#include <nt2/reduction/include/functions/scalar/dot.hpp>

#endif
